@@ -5,7 +5,7 @@ import streamlit.components.v1 as components
 # the component, and True when we're ready to package and distribute it.
 # (This is, of course, optional - there are innumerable ways to manage your
 # release process.)
-_RELEASE = True
+_RELEASE = False
 
 # Declare a Streamlit component. `declare_component` returns a function
 # that is used to create instances of the component. We're naming this
@@ -65,7 +65,27 @@ if not _RELEASE:
     # print its output value.
     #uploaded_file = file_upload_ven(menu=["World","Hello","Test"],group_names=["World","Hello","Test"],text_groups=[],summaries="dfdffdfddfsfsdfsfsfssd",topics='dffdsfsfsfsfsd',generated_number_groups=7, False)
     uploaded_file = file_upload_ven(["World","Hello","Test"],"Group Name",['list 1','list 2','list 3','list 4'],"It is a long established fact that a reader will be distracted by the readable content of a page when looking at its layout. The point of using Lorem Ipsum is that it has a more-or-less normal distribution of letters, as opposed to using 'Content here, content here', making it look like readable English. Many desktop publishing packages and web page editors now use Lorem Ipsum as their default model text, and a search for 'lorem ipsum' will uncover many web sites still in their infancy. Various versions have evolved over the years, sometimes by accident, sometimes on purpose (injected humour and the like)",'dffdsfsfsfsfsd',10, False)
-    
+    similarity_score = st.slider('Similarity Score', 0.0, 1.0, 0.7)
+    st.markdown(
+        """
+            <style>
+            .stSlider {
+            background-color: #32333d;
+            # border: 1px solid #CCCCCC;
+            width:  70% !important;  
+            padding: 0.7% 0.7% 0.7% 0.7%;
+            border-radius: 0.25rem;
+            }
+            .css-1di9i1a {
+    width: 1088px;
+    position: relative;
+    display: flex;
+    justify-content: center;
+}
+            </style>
+            """,
+        unsafe_allow_html=True,
+    )
     if uploaded_file is not None:
         # To read file as bytes:
         #bytes_data = uploaded_file.getvalue()
